(comp->> f & fs)Like comp but multiple arguments are passed to all functions like partial, except the last which is threaded like ->>
Like comp but multiple arguments are passed to all functions like partial, except the last which is threaded like ->>
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |